@@ -2,13 +2,12 @@
 from jax.config import config
 
 from gdec.eld import EmpiricalLinearDecoder
-from gdec.gid import GaussianIndependentDecoder
+from gdec.gid import GaussianIndependentDecoder, LinearGaussianIndependentDecoder
 from gdec.glmnet import LogisticRegression
 from gdec.gpgid import GPGaussianIndependentDecoder
 from gdec.gppid import GPPoissonIndependentDecoder
 from gdec.pid import PoissonIndependentDecoder
 from gdec.snd import SuperNeuronDecoder
-from gdec.vgpmd import VariationalGaussianProcessMulticlassDecoder
 from gdec.vgpmd import (
     VariationalGaussianProcessMulticlassDecoder as GaussianProcessMulticlassDecoder,
 )
@@ -17,6 +16,7 @@ config.update("jax_enable_x64", True)
 
 __all__ = [
     "EmpiricalLinearDecoder",
+    "LinearGaussianIndependentDecoder",
     "GaussianIndependentDecoder",
     "GPGaussianIndependentDecoder",
     "GPPoissonIndependentDecoder",
